创建一个完整的项目 | NoneBot
Description: 跨平台 Python 异步 QQ 机器人框架

# # 创建一个完整的项目

上一章中我们已经运行了一个最小的 NoneBot 实例，在这一章，我们将从零开始一个完整的项目。

## # 目录结构

首先，我们可以使用 `nb-cli` 或者自行创建完整的项目目录：

    nb create

1

    AweSome-Bot
    ├── awesome_bot (或是 src)
    │   └── plugins
    ├── .env (可选的)
    ├── .env.dev (可选的)
    ├── .env.prod (可选的)
    ├── .gitignore
    ├── bot.py
    ├── docker-compose.yml
    ├── Dockerfile
    ├── pyproject.toml
    └── README.md

- `awesome_bot/plugins` 或 `src/plugins`: 用于存放编写的 bot 插件
- `.env`, `.env.dev`, `.env.prod`: 各环境配置文件
- `bot.py`: bot 入口文件
- `pyproject.toml`: 项目依赖管理文件，默认使用 poetry
  (opens new window)

## # 启动 Bot

如果你使用 `nb-cli`

    nb run [--file=bot.py] [--app=app]

1

或者使用

    python bot.py

1

提示

如果在 bot 入口文件内定义了 asgi server， `nb-cli` 将会为你启动冷重载模式